Package: rscc
Type: Package
Title: R Source Code Similarity Evaluation by Variable/Function Names
Version: 0.2.1
Date: 2022-01-20
Authors@R: 
  c(person("Sigbert", "Klinke", email="sigbert@hu-berlin.de", role=c("aut", "cre")))
Description: Evaluates R source codes by variable and/or functions names. Similar source codes should deliver similarity coefficients near one. Since neither the frequency nor the order of the used names is considered, a manual inspection of the R source code is required to check for similarity. Possible use cases include detection of code clones for improving
    software quality and of plagiarism amongst students' assignments.
License: GPL-3
URL: https://github.com/sigbertklinke/rscc (development version)
Imports: crayon, formatR, highlight, igraph, tm
Encoding: UTF-8
RoxygenNote: 7.1.2
Suggests: rmarkdown, knitr
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2022-01-20 11:31:07 UTC; sk
Author: Sigbert Klinke [aut, cre]
Maintainer: Sigbert Klinke <sigbert@hu-berlin.de>
Repository: CRAN
Date/Publication: 2022-01-20 12:02:42 UTC
Built: R 4.6.0; ; 2026-04-27 19:58:21 UTC; unix
