# Generated by roxygen2: do not edit by hand

S3method(sourcecode,default)
export(as_igraph)
export(browse)
export(documents)
export(freq_table)
export(matrix2dataframe)
export(same_file)
export(similarities)
export(similarity_coeff)
export(sims)
export(sourcecode)
export(tfidf)
importFrom(crayon,red)
importFrom(formatR,tidy_source)
importFrom(highlight,highlight)
importFrom(highlight,renderer_html)
importFrom(igraph,graph_from_adjacency_matrix)
importFrom(tm,Corpus)
importFrom(tm,TermDocumentMatrix)
importFrom(tm,VectorSource)
importFrom(utils,browseURL)
