# rscc 

Compares R code in files or expressions and computes similarity coefficients for them.

View the vignette on [GitHub](https://htmlpreview.github.io/?https://github.com/sigbertklinke/rscc/blob/master/vignettes/rscc.html) or after installing with

```R
library("rscc")
vignette("rscc") 
```

# Installation  

## From CRAN

```R
install.packages("rscc")
```

## From github

Note that from github you install the current development version.

```R
library("devtools")
install_github("sigbertklinke/rscc")
```

# History
  * 2022-01-20 version 0.2.1, improved documentation & HTML output, faster computation
  * 2021-09-09 version 0.1.0
